==> icons-vue-0.3.0.tgz: package/es/light--filled/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../chunk-75bb93d0.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_LightFilled20 = {
  name: 'LightFilled20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M15 2H17V6.96H15z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M21.67 6.85H26.630000000000003V8.85H21.67z",
        "transform": "rotate(-45 24.142 7.85)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M25.04 15H30V17H25.04z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M23.15 21.67H25.15V26.630000000000003H23.15z",
        "transform": "rotate(-45 24.152 24.146)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M15 25.04H17V30H15z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M5.37 23.15H10.33V25.15H5.37z",
        "transform": "rotate(-45 7.86 24.144)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M2 15H6.96V17H2z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M6.85 5.37H8.85V10.33H6.85z",
        "transform": "rotate(-45 7.85 7.848)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,10a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
      }
    }), children]);
  }
};

export default virtual_LightFilled20;

==> icons-vue-0.6.0.tgz: package/es/light--filled/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_LightFilled20 = {
  name: 'LightFilled20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4.96",
        "x": "15",
        "y": "2"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4.96",
        "height": "2",
        "x": "21.67",
        "y": "6.85",
        "transform": "rotate(-45 24.142 7.85)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4.96",
        "height": "2",
        "x": "25.04",
        "y": "15"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4.96",
        "x": "23.15",
        "y": "21.67",
        "transform": "rotate(-45 24.152 24.146)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4.96",
        "x": "15",
        "y": "25.04"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4.96",
        "height": "2",
        "x": "5.37",
        "y": "23.15",
        "transform": "rotate(-45 7.86 24.144)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4.96",
        "height": "2",
        "x": "2",
        "y": "15"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4.96",
        "x": "6.85",
        "y": "5.37",
        "transform": "rotate(-45 7.85 7.848)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,10a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
      }
    }), children]);
  }
};

export default virtual_LightFilled20;
